@@ -9,15 +9,17 @@ from nscms.helpers.upload import UploadTo
 
 class Section(SimpleContentModel):
 
-    class Meta(SimpleContentModel.Meta): 
+    class Meta(SimpleContentModel.Meta):
         abstract = False
         verbose_name = _(u'Section')
-        verbose_name_plural = _(u'Sections')       
-    
-    
-class Banner(ContentModel): 
+        verbose_name_plural = _(u'Sections')
+
+
+class Banner(ContentModel):
     section = models.ForeignKey(
         "Section", verbose_name=_(u'Section'), blank=True, null=True)
     image = models.ImageField(_(u'Image'), upload_to=UploadTo('banners'))
     url = models.URLField(u"URL")
 
+    def __unicode__(self):
+        return self.title.strip() or self.description.strip() or self.url
